MethodChannelSafetyNetFlutter class
An implementation of SafetyNetFlutterPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- SafetyNetFlutterPlatform
- MethodChannelSafetyNetFlutter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
check(
) → Future< SafetyNetCheckResult> -
Runs the security check on this platform and returns the result.
Never disables features or reacts on its own — see
SafetyNetCheckResult's doc comment.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited