SafetyNetFlutterPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- SafetyNetFlutterPlatform
- Implementers
Constructors
- SafetyNetFlutterPlatform()
- Constructs a SafetyNetFlutterPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
check(
) → Future< SafetyNetCheckResult> - Runs the security check on this platform and returns the result. Never disables features or reacts on its own — see SafetyNetCheckResult's doc comment.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SafetyNetFlutterPlatform
-
The default instance of SafetyNetFlutterPlatform to use.
getter/setter pair